# IMPORTANT

This is a pre-release. Please do not use in production.

I have requested permission from the Pulumi team to start working on porting (or bridging) the Terrraform Databricks provider to Pulumi.

We currently use this package in my company (Ingenii Solutions).
